@@ -14,29 +14,11 @@ class PATH_UTILS(Enum):
     SCRIPT_COMMIT = "commit.sh"
     SCRIPT_PUSH = "push.sh"
     SCRIPT_CLEAN = "clean.sh"
-    LIB_NAME = "tf"
 
 @dataclass
 class CLI_Utils():
-    def __init__(self) -> None:
-        """ Search for PATH lib. """
-        self.path = None
-                
-        # Searching for lib dir
-        start = sys.path
-        for x in reversed(range(len(start))):
-            tmp_path = os.path.join(start[x], PATH_UTILS.LIB_NAME.value)
-
-            if os.path.exists(tmp_path):
-                self.path = tmp_path
-                break
-        
-        if self.path is None:
-            raise Exception("Path file not found. Program cannot be used. Make sure the program is installed properly.")
-        
-        # logger.info(f"Program's PATH is at {self.path}")
-        # os.chdir(self.path) # updating CWD to PATH's lib not local
-        self.script_path = os.path.realpath( os.path.join(self.path, PATH_UTILS.SCRIPT_DIR.value) )
+    path:str = os.path.dirname(os.path.realpath(__file__))
+    script_path:str = os.path.realpath( os.path.join(path, PATH_UTILS.SCRIPT_DIR.value) )
 
     def build(self) -> None:
         logger.info("Build is running...")
